@@ -1,14 +1,17 @@
 use crate::{
     channel::{permission_overwrite::PermissionOverwrite, ChannelType},
-    id::{ChannelId, GuildId},
+    id::{
+        marker::{ChannelMarker, GuildMarker},
+        Id,
+    },
 };
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct CategoryChannel {
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub guild_id: Option<GuildId>,
-    pub id: ChannelId,
+    pub guild_id: Option<Id<GuildMarker>>,
+    pub id: Id<ChannelMarker>,
     #[serde(rename = "type")]
     pub kind: ChannelType,
     pub name: String,
@@ -18,14 +21,15 @@ pub struct CategoryChannel {
 
 #[cfg(test)]
 mod tests {
-    use super::{CategoryChannel, ChannelId, ChannelType, GuildId};
+    use super::{CategoryChannel, ChannelType};
+    use crate::id::Id;
     use serde_test::Token;
 
     #[test]
     fn test_category_channel() {
         let value = CategoryChannel {
-            guild_id: Some(GuildId::new(1).expect("non zero")),
-            id: ChannelId::new(2).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(2),
             kind: ChannelType::GuildCategory,
             name: "category".to_owned(),
             permission_overwrites: Vec::new(),
@@ -41,10 +45,10 @@ mod tests {
                 },
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(4),
