@@ -1,7 +1,11 @@
 use crate::{
     datetime::Timestamp,
-    id::{GuildId, RoleId},
+    id::{
+        marker::{GuildMarker, RoleMarker},
+        Id,
+    },
     user::User,
+    util::image_hash::ImageHash,
 };
 
 use serde::{
@@ -17,10 +21,10 @@ use std::fmt::{Formatter, Result as FmtResult};
 pub struct Member {
     /// Member's guild avatar.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub avatar: Option<String>,
+    pub avatar: Option<ImageHash>,
     pub communication_disabled_until: Option<Timestamp>,
     pub deaf: bool,
-    pub guild_id: GuildId,
+    pub guild_id: Id<GuildMarker>,
     pub joined_at: Timestamp,
     pub mute: bool,
     pub nick: Option<String>,
@@ -29,7 +33,7 @@ pub struct Member {
     pub pending: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub premium_since: Option<Timestamp>,
-    pub roles: Vec<RoleId>,
+    pub roles: Vec<Id<RoleMarker>>,
     pub user: User,
 }
 
@@ -43,7 +47,7 @@ pub struct Member {
 pub struct MemberIntermediary {
     /// Member's guild avatar.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub avatar: Option<String>,
+    pub avatar: Option<ImageHash>,
     pub communication_disabled_until: Option<Timestamp>,
     pub deaf: bool,
     pub joined_at: Timestamp,
@@ -53,14 +57,14 @@ pub struct MemberIntermediary {
     pub pending: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub premium_since: Option<Timestamp>,
-    pub roles: Vec<RoleId>,
+    pub roles: Vec<Id<RoleMarker>>,
     pub user: User,
 }
 
 impl MemberIntermediary {
     /// Inject a guild ID to create a [`Member`].
     #[allow(clippy::missing_const_for_fn)] // false positive
-    pub fn into_member(self, guild_id: GuildId) -> Member {
+    pub fn into_member(self, guild_id: Id<GuildMarker>) -> Member {
         Member {
             avatar: self.avatar,
             communication_disabled_until: self.communication_disabled_until,
@@ -83,12 +87,12 @@ impl MemberIntermediary {
 /// Member payloads from the HTTP API, for example, don't have the guild
 /// ID.
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub struct MemberDeserializer(GuildId);
+pub struct MemberDeserializer(Id<GuildMarker>);
 
 impl MemberDeserializer {
     /// Create a new deserializer for a member when you know the ID but the
     /// payload probably doesn't contain it.
-    pub const fn new(guild_id: GuildId) -> Self {
+    pub const fn new(guild_id: Id<GuildMarker>) -> Self {
         Self(guild_id)
     }
 }
@@ -101,7 +105,7 @@ impl<'de> DeserializeSeed<'de> for MemberDeserializer {
     }
 }
 
-pub(crate) struct MemberVisitor(GuildId);
+pub(crate) struct MemberVisitor(Id<GuildMarker>);
 
 impl<'de> Visitor<'de> for MemberVisitor {
     type Value = Member;
@@ -131,12 +135,12 @@ impl<'de> Visitor<'de> for MemberVisitor {
 }
 
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub(crate) struct OptionalMemberDeserializer(GuildId);
+pub(crate) struct OptionalMemberDeserializer(Id<GuildMarker>);
 
 impl OptionalMemberDeserializer {
     /// Create a new deserializer for a member when you know the ID but the
     /// payload probably doesn't contain it.
-    pub const fn new(guild_id: GuildId) -> Self {
+    pub const fn new(guild_id: Id<GuildMarker>) -> Self {
         Self(guild_id)
     }
 }
@@ -149,7 +153,7 @@ impl<'de> DeserializeSeed<'de> for OptionalMemberDeserializer {
     }
 }
 
-struct OptionalMemberVisitor(GuildId);
+struct OptionalMemberVisitor(Id<GuildMarker>);
 
 impl<'de> Visitor<'de> for OptionalMemberVisitor {
     type Value = Option<Member>;
@@ -168,17 +172,17 @@ impl<'de> Visitor<'de> for OptionalMemberVisitor {
 }
 
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub struct MemberListDeserializer(GuildId);
+pub struct MemberListDeserializer(Id<GuildMarker>);
 
 impl MemberListDeserializer {
     /// Create a new deserializer for a map of members when you know the
     /// Guild ID but the payload probably doesn't contain it.
-    pub const fn new(guild_id: GuildId) -> Self {
+    pub const fn new(guild_id: Id<GuildMarker>) -> Self {
         Self(guild_id)
     }
 }
 
-struct MemberListVisitor(GuildId);
+struct MemberListVisitor(Id<GuildMarker>);
 
 impl<'de> Visitor<'de> for MemberListVisitor {
     type Value = Vec<Member>;
@@ -211,7 +215,8 @@ mod tests {
     use super::Member;
     use crate::{
         datetime::{Timestamp, TimestampParseError},
-        id::{GuildId, UserId},
+        id::Id,
+        test::image_hash,
         user::User,
     };
     use serde_test::Token;
@@ -223,10 +228,10 @@ mod tests {
         let premium_since = Timestamp::from_str("2021-03-16T14:29:19.046000+00:00")?;
 
         let value = Member {
-            avatar: Some("guild avatar".to_owned()),
+            avatar: Some(image_hash::AVATAR),
             communication_disabled_until: None,
             deaf: false,
-            guild_id: GuildId::new(1).expect("non zero"),
+            guild_id: Id::new(1),
             joined_at,
             mute: true,
             nick: Some("twilight".to_owned()),
@@ -241,7 +246,7 @@ mod tests {
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(3).expect("non zero"),
+                id: Id::new(3),
                 locale: None,
                 mfa_enabled: None,
                 name: "twilight".to_owned(),
@@ -261,13 +266,13 @@ mod tests {
                 },
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("guild avatar"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("communication_disabled_until"),
                 Token::None,
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("joined_at"),
                 Token::Str("2015-04-26T06:26:56.936000+00:00"),
@@ -300,7 +305,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("username"),
                 Token::Str("twilight"),
@@ -319,10 +324,10 @@ mod tests {
         let premium_since = Timestamp::from_str("2021-03-16T14:29:19.046000+00:00")?;
 
         let value = Member {
-            avatar: Some("guild avatar".to_owned()),
+            avatar: Some(image_hash::AVATAR),
             communication_disabled_until: Some(communication_disabled_until),
             deaf: false,
-            guild_id: GuildId::new(1).expect("non zero"),
+            guild_id: Id::new(1),
             joined_at,
             mute: true,
             nick: Some("twilight".to_owned()),
@@ -337,7 +342,7 @@ mod tests {
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(3).expect("non zero"),
+                id: Id::new(3),
                 locale: None,
                 mfa_enabled: None,
                 name: "twilight".to_owned(),
@@ -357,14 +362,14 @@ mod tests {
                 },
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("guild avatar"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("communication_disabled_until"),
                 Token::Some,
                 Token::Str("2021-12-23T14:29:19.046000+00:00"),
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("joined_at"),
                 Token::Str("2015-04-26T06:26:56.936000+00:00"),
@@ -397,7 +402,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("username"),
                 Token::Str("twilight"),
