@@ -58,7 +58,8 @@ mod tests {
         channel::ChannelType,
         datetime::{Timestamp, TimestampParseError},
         guild::VerificationLevel,
-        id::{ChannelId, EmojiId, GuildId, UserId},
+        id::Id,
+        test::image_hash,
     };
     use serde::{Deserialize, Serialize};
     use serde_test::Token;
@@ -100,7 +101,7 @@ mod tests {
             approximate_member_count: Some(31),
             approximate_presence_count: Some(7),
             channel: Some(InviteChannel {
-                id: ChannelId::new(2).expect("non zero"),
+                id: Id::new(2),
                 kind: ChannelType::Group,
                 name: None,
             }),
@@ -138,7 +139,7 @@ mod tests {
                     len: 2,
                 },
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(3),
@@ -164,7 +165,7 @@ mod tests {
             approximate_member_count: Some(31),
             approximate_presence_count: Some(7),
             channel: Some(InviteChannel {
-                id: ChannelId::new(2).expect("non zero"),
+                id: Id::new(2),
                 kind: ChannelType::Group,
                 name: None,
             }),
@@ -172,28 +173,28 @@ mod tests {
             created_at: Some(created_at),
             expires_at: Some(expires_at),
             guild: Some(InviteGuild {
-                banner: Some("banner hash".to_owned()),
+                banner: Some(image_hash::BANNER),
                 description: Some("a description".to_owned()),
                 features: vec!["a feature".to_owned()],
-                icon: Some("icon hash".to_owned()),
-                id: GuildId::new(1).expect("non zero"),
+                icon: Some(image_hash::ICON),
+                id: Id::new(1),
                 name: "guild name".to_owned(),
-                splash: Some("splash hash".to_owned()),
+                splash: Some(image_hash::SPLASH),
                 vanity_url_code: Some("twilight".to_owned()),
                 verification_level: VerificationLevel::Medium,
                 welcome_screen: Some(WelcomeScreen {
                     description: Some("welcome description".to_owned()),
                     welcome_channels: vec![
                         WelcomeScreenChannel {
-                            channel_id: ChannelId::new(123).expect("non zero"),
+                            channel_id: Id::new(123),
                             description: "channel description".to_owned(),
                             emoji_id: None,
                             emoji_name: Some("\u{1f352}".to_owned()),
                         },
                         WelcomeScreenChannel {
-                            channel_id: ChannelId::new(456).expect("non zero"),
+                            channel_id: Id::new(456),
                             description: "custom description".to_owned(),
-                            emoji_id: Some(EmojiId::new(789).expect("non zero")),
+                            emoji_id: Some(Id::new(789)),
                             emoji_name: Some("custom_name".to_owned()),
                         },
                     ],
@@ -207,7 +208,7 @@ mod tests {
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(2).expect("non zero"),
+                id: Id::new(2),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -234,7 +235,7 @@ mod tests {
                         discriminator: 1,
                         email: None,
                         flags: None,
-                        id: UserId::new(2).expect("non zero"),
+                        id: Id::new(2),
                         locale: None,
                         mfa_enabled: None,
                         name: "test".to_owned(),
@@ -257,7 +258,7 @@ mod tests {
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(2).expect("non zero"),
+                id: Id::new(2),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -290,7 +291,7 @@ mod tests {
                     len: 2,
                 },
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(3),
@@ -311,7 +312,7 @@ mod tests {
                 },
                 Token::Str("banner"),
                 Token::Some,
-                Token::Str("banner hash"),
+                Token::Str(image_hash::BANNER_INPUT),
                 Token::Str("description"),
                 Token::Some,
                 Token::Str("a description"),
@@ -321,15 +322,15 @@ mod tests {
                 Token::SeqEnd,
                 Token::Str("icon"),
                 Token::Some,
-                Token::Str("icon hash"),
+                Token::Str(image_hash::ICON_INPUT),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("name"),
                 Token::Str("guild name"),
                 Token::Str("splash"),
                 Token::Some,
-                Token::Str("splash hash"),
+                Token::Str(image_hash::SPLASH_INPUT),
                 Token::Str("vanity_url_code"),
                 Token::Some,
                 Token::Str("twilight"),
@@ -351,7 +352,7 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("123"),
                 Token::Str("description"),
                 Token::Str("channel description"),
@@ -366,13 +367,13 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("456"),
                 Token::Str("description"),
                 Token::Str("custom description"),
                 Token::Str("emoji_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "EmojiId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("789"),
                 Token::Str("emoji_name"),
                 Token::Some,
@@ -398,7 +399,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("username"),
                 Token::Str("test"),
@@ -439,7 +440,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("username"),
                 Token::Str("test"),
@@ -473,7 +474,7 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("username"),
                 Token::Str("test"),
